@@ -1,10 +1,10 @@
 #' Print summary of distance detection function model object
-#' 
+#'
 #' Provides a brief summary of data and fitted detection probability model
 #' parameters, model selection criterion, and optionally abundance in the
 #' covered (sampled) region and its standard error. What is printed depends
 #' on the corresponding call to summary.
-#' 
+#'
 #' @aliases print.summary.io
 #' @method print summary.io
 #' @S3method print summary.io
@@ -14,19 +14,7 @@
 #' @author Jeff Laake
 #' @seealso \code{\link{summary.io}}
 #' @keywords utility
-print.summary.io <-
-function(x,...)
-{
-#
-# print.summmary.io
-#
-# Provides a summary of parameters and estimates from the output of io object
-#
-# Arguments:
-#
-# x     - object from summary.io
-#
-# Value: Null
+print.summary.io <- function(x,...){
 
   print(x$mr.summary)
   cat("\n")
@@ -34,12 +22,11 @@ function(x,...)
   cat("\n\nSummary for io object\n")
   cat("Total AIC value : ",x$AIC,"\n\n")
 
-  parameters=data.frame(Estimate=c(x$average.p,x$Nhat))
-  row.names(parameters)=c("Average p", "N in covered region")
-  if(!is.null(x$average.p.se))
-  {
-      parameters$SE=c(x$average.p.se,x$Nhat.se)
-      parameters$CV=parameters$SE/parameters$Estimate
+  parameters <- data.frame(Estimate=c(x$average.p,x$Nhat))
+  row.names(parameters) <- c("Average p", "N in covered region")
+  if(!is.null(x$average.p.se)){
+    parameters$SE <- c(x$average.p.se,x$Nhat.se)
+    parameters$CV <- parameters$SE/parameters$Estimate
   }
   print(parameters)
   invisible(NULL)
